Credits — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# Credits

Information about the crew behind Transifex can be found at:

- http://transifex.org/wiki/Development/Crew

Thanks to everyone who contributed code for Transifex. In addition, a big ‘Thanks!’ to:

- Google, for its exciting ‘Summer of Code’ program
- The Fedora Project, for its amazing people
- GNOME, for the ‘damned lies’ translation statistics program
- Luke Macken’s bodhi update system, used extensively as a reference point
- Conference organizers for giving the chance to spread the word
- Everyone who provided feedback and ideas for improvement